@@ -1,4 +1,4 @@
-""" Kucoin exchange subclass """
+"""Kucoin exchange subclass."""
 import logging
 from typing import Dict
 
@@ -9,9 +9,9 @@ logger = logging.getLogger(__name__)
 
 
 class Kucoin(Exchange):
-    """
-    Kucoin exchange class. Contains adjustments needed for Freqtrade to work
-    with this exchange.
+    """Kucoin exchange class.
+
+    Contains adjustments needed for Freqtrade to work with this exchange.
 
     Please note that this exchange is not included in the list of exchanges
     officially supported by the Freqtrade development team. So some features
@@ -21,4 +21,6 @@ class Kucoin(Exchange):
     _ft_has: Dict = {
         "l2_limit_range": [20, 100],
         "l2_limit_range_required": False,
+        "order_time_in_force": ['gtc', 'fok', 'ioc'],
+        "time_in_force_parameter": "timeInForce",
     }
