@@ -185,17 +185,18 @@ def test_get_trade_stake_amount_unlimited_amount(default_conf, ticker, balance_r
     (100, 11, 500, 100),
     (1000, 11, 500, 500),  # Above max-stake
     (20, 15, 10, 0),  # Minimum stake > max-stake
-    (1, 11, 100, 11),  # Below min stake
+    (9, 11, 100, 11),  # Below min stake
     (1, 15, 10, 0),  # Below min stake and min_stake > max_stake
+    (20, 50, 100, 0),  # Below min stake and stake * 1.3 > min_stake
 
 ])
-def test__validate_stake_amount(mocker, default_conf,
-                                stake_amount, min_stake_amount, max_stake_amount, expected):
+def test_validate_stake_amount(mocker, default_conf,
+                               stake_amount, min_stake_amount, max_stake_amount, expected):
     freqtrade = get_patched_freqtradebot(mocker, default_conf)
 
     mocker.patch("freqtrade.wallets.Wallets.get_available_stake_amount",
                  return_value=max_stake_amount)
-    res = freqtrade.wallets._validate_stake_amount('XRP/USDT', stake_amount, min_stake_amount)
+    res = freqtrade.wallets.validate_stake_amount('XRP/USDT', stake_amount, min_stake_amount)
     assert res == expected
 
 
